==> piwigo-2.5.3.zip: piwigo/language/zh_HK/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = '數據庫表將使用前綴詞(它另您更好管理)';
$lang['enter a login for webmaster'] = '輸入網站管理員登錄名稱';
$lang['please enter your password again'] = '請您再次輸入密碼';
$lang['user login given by your host provider'] = '供應商姶你的登錄用戶名稱';
$lang['user password given by your host provider'] = '供應商姶你的登錄用戶密碼';
$lang['verification'] = '驗證';
$lang['webmaster login can\'t contain characters \' or "'] = '網站管理員登錄名稱不能包含字符\'或"';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = '需要幫助嗎？你可以在<a href="%s">Piwigo 留言板</a>提出問題。';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = '注意：你可以更改設定，然後重新啟動Piwigo。';
$lang['PHP 5 is required'] = '需要PHP5';
$lang['Password ']['confirm'] = '密碼[確認]';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo嘗試建立或修改您的.htaccess檔案, 來設定系統使用PHP5。';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo的無法設定使用PHP5。';
$lang['Sorry!'] = '對不起！';
$lang['Start Install'] = '開始安裝';
$lang['Try to configure PHP 5'] = '嘗試設定PHP5';
$lang['User'] = '用戶';
$lang['Visitors will be able to contact site administrator with this mail'] = '訪客可以使用這個電子郵件與網站管理員聯繫';
$lang['Welcome to my photo gallery'] = '歡迎來到我的相簿';
$lang['Welcome to your new installation of Piwigo!'] = '歡迎來到你新安裝的Piwigo！';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = '您可以下載設定檔案，並裝它上傳到local/config目錄中安裝。';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = '請聯繫你的網站託管服務提供商，看看你怎麼可以自己切換到PHP 5。';
$lang['also given by your host provider'] = '也可由網站託管服務提供商幫助設定';
$lang['Admin configuration'] = '管理員設定';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = '另一種解決方案是將上面框中的文字複製，並貼到檔案 "local/config/database.inc.php"上 （警告：database.inc.php只可以包括文字框內容,不可以有，或空格字符）';
$lang['Basic configuration'] = '基本設定';
$lang['Can\'t connect to server'] = '無法連接到伺服器';
$lang['Congratulations, Piwigo installation is completed'] = '恭喜你，Piwigo已安裝完成';
$lang['Connection to server succeed, but it was impossible to connect to database'] = '成功連接到伺服器, 但不能連接到數據庫。';
$lang['Creation of config file local/config/database.inc.php failed.'] = '無法創建設定檔案 local/config/database.inc.php。';
$lang['Database configuration'] = '數據庫設定';
$lang['Database name'] = '數據庫名稱';
$lang['Database table prefix'] = '數據庫表格前置詞';
$lang['Default gallery language'] = '預設相簿語言';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = '如需要任何幫助,請不要猶豫到我們的論壇諮詢:%s';
$lang['Download the config file'] = '下載設定檔案。';
$lang['Hope to see you back soon.'] = '希望盡快看到你回來。';
$lang['Host'] = '主機';
$lang['Installation'] = '安裝';
$lang['It appears your webhost is currently running PHP %s.'] = '目前您的網頁寄存伺服器運行PHP %s。';
$lang['It will be shown to the visitors. It is necessary for website administration'] = '這是必要的網站管理,因它會顯示給所有訪客。';
$lang['Just another Piwigo gallery'] = '只是另一個Piwigo相簿';
$lang['Keep it confidential, it enables you to access administration panel'] = '請保密，它使您能夠訪問管理面板';
$lang['localhost or other, supplied by your host provider'] = '本地主機或其它，由你的主機提供商提供';
?>

==> piwigo-16.1.0.zip: piwigo/language/zh_HK/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+

$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = '數據庫表將使用前綴詞(它另您更好管理)';
$lang['enter a login for webmaster'] = '輸入網站管理員登錄名稱';
$lang['please enter your password again'] = '請您再次輸入密碼';
$lang['user login given by your host provider'] = '供應商姶你的登錄用戶名稱';
$lang['user password given by your host provider'] = '供應商姶你的登錄用戶密碼';
$lang['verification'] = '驗證';
$lang['webmaster login can\'t contain characters \' or "'] = '網站管理員登錄名稱不能包含字符\'或"';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = '需要幫助嗎？你可以在<a href="%s">Piwigo 留言板</a>提出問題。';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = '注意：你可以更改設定，然後重新啟動Piwigo。';
$lang['PHP 5 is required'] = '需要PHP5.2';
$lang['Password ']['confirm'] = '密碼[確認]';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo嘗試建立或修改您的.htaccess檔案, 來設定系統使用PHP5.2。';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo的無法設定使用PHP5.2。';
$lang['Sorry!'] = '對不起！';
$lang['Start Install'] = '開始安裝';
$lang['Try to configure PHP 5'] = '嘗試設定PHP5.2';
$lang['User'] = '用戶';
$lang['Visitors will be able to contact site administrator with this mail'] = '訪客可以使用這個電子郵件與網站管理員聯繫';
$lang['Welcome to my photo gallery'] = '歡迎來到我的相簿';
$lang['Welcome to your new installation of Piwigo!'] = '歡迎來到你新安裝的Piwigo！';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = '您可以下載設定檔案，並裝它上傳到local/config目錄中安裝。';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = '請聯繫你的網站託管服務提供商，看看你怎麼可以自己切換到PHP 5.2。';
$lang['also given by your host provider'] = '也可由網站託管服務提供商幫助設定';
$lang['Admin configuration'] = '管理員設定';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = '另一種解決方案是將上面框中的文字複製，並貼到檔案 "local/config/database.inc.php"上 （警告：database.inc.php只可以包括文字框內容,不可以有，或空格字符）';
$lang['Basic configuration'] = '基本設定';
$lang['Can\'t connect to server'] = '無法連接到伺服器';
$lang['Congratulations, Piwigo installation is completed'] = '恭喜你，Piwigo已安裝完成';
$lang['Connection to server succeed, but it was impossible to connect to database'] = '成功連接到伺服器, 但不能連接到數據庫。';
$lang['Creation of config file local/config/database.inc.php failed.'] = '無法創建設定檔案 local/config/database.inc.php。';
$lang['Database configuration'] = '數據庫設定';
$lang['Database name'] = '數據庫名稱';
$lang['Database table prefix'] = '數據庫表格前置詞';
$lang['Default gallery language'] = '預設相簿語言';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = '如需要任何幫助,請不要猶豫到我們的論壇諮詢:%s';
$lang['Download the config file'] = '下載設定檔案。';
$lang['Hope to see you back soon.'] = '希望盡快看到你回來。';
$lang['Host'] = '主機';
$lang['Installation'] = '安裝';
$lang['It appears your webhost is currently running PHP %s.'] = '目前您的網頁寄存伺服器運行PHP %s。';
$lang['It will be shown to the visitors. It is necessary for website administration'] = '這是必要的網站管理,因它會顯示給所有訪客。';
$lang['Just another Piwigo gallery'] = '只是另一個Piwigo相簿';
$lang['Keep it confidential, it enables you to access administration panel'] = '請保密，它使您能夠訪問管理面板';
$lang['localhost or other, supplied by your host provider'] = '本地主機或其它，由你的主機提供商提供';
